@@ -8,44 +8,39 @@
 **
 ** This file is part of the QtSerialPort module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL$
+** $QT_BEGIN_LICENSE:LGPL21$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia.  For licensing terms and
-** conditions see http://qt.digia.com/licensing.  For further information
+** a written agreement between you and Digia. For licensing terms and
+** conditions see http://qt.digia.com/licensing. For further information
 ** use the contact form at http://qt.digia.com/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 2.1 or version 3 as published by the Free
+** Software Foundation and appearing in the file LICENSE.LGPLv21 and
+** LICENSE.LGPLv3 included in the packaging of this file. Please review the
+** following information to ensure the GNU Lesser General Public License
+** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Digia gives you certain additional
-** rights.  These rights are described in the Digia Qt LGPL Exception
+** rights. These rights are described in the Digia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
-**
-**
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
 #include "qserialport.h"
 #include "qserialportinfo.h"
+#include "qserialportinfo_p.h"
 
-#ifdef Q_OS_WIN
+#ifdef Q_OS_WINCE
+#include "qserialport_wince_p.h"
+#elif defined (Q_OS_WIN)
 #include "qserialport_win_p.h"
 #elif defined (Q_OS_SYMBIAN)
 #include "qserialport_symbian_p.h"
@@ -68,14 +63,16 @@ QSerialPortPrivateData::QSerialPortPrivateData(QSerialPort *q)
     , readBuffer(SERIALPORT_BUFFERSIZE)
     , writeBuffer(SERIALPORT_BUFFERSIZE)
     , error(QSerialPort::NoError)
-    , inputBaudRate(0)
-    , outputBaudRate(0)
+    , inputBaudRate(9600)
+    , outputBaudRate(9600)
     , dataBits(QSerialPort::Data8)
     , parity(QSerialPort::NoParity)
     , stopBits(QSerialPort::OneStop)
-    , flow(QSerialPort::NoFlowControl)
+    , flowControl(QSerialPort::NoFlowControl)
     , policy(QSerialPort::IgnorePolicy)
+#if QT_DEPRECATED_SINCE(5,3)
     , settingsRestoredOnClose(true)
+#endif
     , q_ptr(q)
 {
 }
@@ -212,12 +209,12 @@ int QSerialPortPrivateData::timeoutValue(int msecs, int elapsed)
 
     \value Data5            The number of data bits in each character is 5. It
                             is used for Baudot code. It generally only makes
-                            sense with older equipments such as teleprinters.
+                            sense with older equipment such as teleprinters.
     \value Data6            The number of data bits in each character is 6. It
                             is rarely used.
     \value Data7            The number of data bits in each character is 7. It
                             is used for true ASCII. It generally only makes
-                            sense with older equipments such as teleprinters.
+                            sense with older equipment such as teleprinters.
     \value Data8            The number of data bits in each character is 8. It
                             is used for most kinds of data, as this size matches
                             the size of a byte. It is almost universally used in
@@ -261,9 +258,9 @@ int QSerialPortPrivateData::timeoutValue(int msecs, int elapsed)
     This enum describes the number of stop bits used.
 
     \value OneStop          1 stop bit.
-    \value OneAndHalfStop   1.5 stop bits. This is only for Windows platform.
+    \value OneAndHalfStop   1.5 stop bits. This is only for the Windows platform.
     \value TwoStop          2 stop bits.
-    \value UnknownStopBits  Unknown number of stop bit. This value is obsolete.
+    \value UnknownStopBits  Unknown number of stop bits. This value is obsolete.
                             It is provided to keep old source code working. We
                             strongly advise against using it in new code.
 
@@ -320,7 +317,7 @@ int QSerialPortPrivateData::timeoutValue(int msecs, int elapsed)
     while parity errors were detected.
 
     \value SkipPolicy           Skips the bad character.
-    \value PassZeroPolicy       Replaces bad character to zero.
+    \value PassZeroPolicy       Replaces bad character with zero.
     \value IgnorePolicy         Ignores the error for a bad character.
     \value StopReceivingPolicy  Stops data reception on error.
     \value UnknownPolicy        Unknown policy.
@@ -421,14 +418,15 @@ QSerialPort::QSerialPort(const QSerialPortInfo &serialPortInfo, QObject *parent)
 QSerialPort::~QSerialPort()
 {
     /**/
-    close();
+    if (isOpen())
+        close();
     delete d_ptr;
 }
 
 /*!
     Sets the \a name of the serial port.
 
-    The name of the serial port can be passed on as either a short name or
+    The name of the serial port can be passed as either a short name or
     the long system location if necessary.
 
     \sa portName(), QSerialPortInfo
@@ -436,7 +434,7 @@ QSerialPort::~QSerialPort()
 void QSerialPort::setPortName(const QString &name)
 {
     Q_D(QSerialPort);
-    d->systemLocation = QSerialPortPrivate::portNameToSystemLocation(name);
+    d->systemLocation = QSerialPortInfoPrivate::portNameToSystemLocation(name);
 }
 
 /*!
@@ -447,13 +445,13 @@ void QSerialPort::setPortName(const QString &name)
 void QSerialPort::setPort(const QSerialPortInfo &serialPortInfo)
 {
     Q_D(QSerialPort);
-    d->systemLocation = QSerialPortPrivate::portNameToSystemLocation(serialPortInfo.systemLocation());
+    d->systemLocation = serialPortInfo.systemLocation();
 }
 
 /*!
-    Returns the name set by setPort() or to the QSerialPort constructors.
-    This name is short, i.e. it extract and convert out from the internal
-    variable system location of the device. Conversion algorithm is
+    Returns the name set by setPort() or passed to the QSerialPort constructor.
+    This name is short, i.e. it is extracted and converted from the internal
+    variable system location of the device. The conversion algorithm is
     platform specific:
     \table
     \header
@@ -461,27 +459,20 @@ void QSerialPort::setPort(const QSerialPortInfo &serialPortInfo)
         \li Brief Description
     \row
         \li Windows
-        \li Removes the prefix "\\\\.\\" from the system location
+        \li Removes the prefix "\\\\.\\" or "//./" from the system location
            and returns the remainder of the string.
     \row
         \li Windows CE
-        \li Removes the postfix ":" from the system location
+        \li Removes the suffix ":" from the system location
            and returns the remainder of the string.
     \row
         \li Symbian
         \li Returns the system location as it is,
            as it is equivalent to the port name.
     \row
-        \li GNU/Linux
+        \li Unix, BSD
         \li Removes the prefix "/dev/" from the system location
            and returns the remainder of the string.
-    \row
-        \li Mac OSX
-        \li Removes the prefix "/dev/cu." and "/dev/tty." from the
-           system location and returns the remainder of the string.
-    \row
-        \li Other *nix
-        \li  The same as for GNU/Linux.
     \endtable
 
     \sa setPort(), QSerialPortInfo::portName()
@@ -489,7 +480,7 @@ void QSerialPort::setPort(const QSerialPortInfo &serialPortInfo)
 QString QSerialPort::portName() const
 {
     Q_D(const QSerialPort);
-    return QSerialPortPrivate::portNameFromSystemLocation(d->systemLocation);
+    return QSerialPortInfoPrivate::portNameFromSystemLocation(d->systemLocation);
 }
 
 /*!
@@ -499,9 +490,9 @@ QString QSerialPort::portName() const
     successful; otherwise returns false and sets an error code which can be
     obtained by calling the error() method.
 
-    \note This method has to be called before setting certain serial port
-    parameters. See each property documentation for details when it is
-    necessary.
+    \note The method returns false if opening the port is successful, but could
+    not set any of the port settings successfully. In that case, the port is
+    closed automatically not to leave the port around with incorrect settings.
 
     \warning The \a mode has to be QIODevice::ReadOnly, QIODevice::WriteOnly,
     or QIODevice::ReadWrite. Other modes are unsupported.
@@ -525,15 +516,20 @@ bool QSerialPort::open(OpenMode mode)
     }
 
     clearError();
-    if (d->open(mode)) {
-        QIODevice::open(mode);
+    if (!d->open(mode))
+        return false;
 
-        d->dataTerminalReady = isDataTerminalReady();
-        d->requestToSend = isRequestToSend();
-
-        return true;
+    if (!d->setBaudRate()
+        || !d->setDataBits(d->dataBits)
+        || !d->setParity(d->parity)
+        || !d->setStopBits(d->stopBits)
+        || !d->setFlowControl(d->flowControl)) {
+        d->close();
+        return false;
     }
-    return false;
+
+    QIODevice::open(mode);
+    return true;
 }
 
 /*!
@@ -558,13 +554,15 @@ void QSerialPort::close()
 
 /*!
     \property QSerialPort::settingsRestoredOnClose
-    \brief the flag which allows to restore the previous settings while closing
+    \brief the flag which specifies to restore the previous settings when closing
     the serial port.
+    \obsolete
 
     If this flag is true, the settings will be restored; otherwise not.
-    The default state of the QSerialPort class is configured to restore the
+    The default state of the QSerialPort class is to restore the
     settings.
 */
+#if QT_DEPRECATED_SINCE(5,3)
 void QSerialPort::setSettingsRestoredOnClose(bool restore)
 {
     Q_D(QSerialPort);
@@ -580,13 +578,14 @@ bool QSerialPort::settingsRestoredOnClose() const
     Q_D(const QSerialPort);
     return d->settingsRestoredOnClose;
 }
-
+#endif // QT_DEPRECATED_SINCE(5,3)
 /*!
     \fn void QSerialPort::settingsRestoredOnCloseChanged(bool restore)
+    \obsolete
 
-    This signal is emitted after the flag which allows to restore the
+    This signal is emitted after the flag which specifies to restore the
     previous settings while closing the serial port has been changed. The new
-    flag which allows to restore the previous settings while closing the serial
+    flag which specifies to restore the previous settings while closing the serial
     port is passed as \a restore.
 
     \sa QSerialPort::settingsRestoredOnClose
@@ -596,35 +595,29 @@ bool QSerialPort::settingsRestoredOnClose() const
     \property QSerialPort::baudRate
     \brief the data baud rate for the desired direction
 
-    If the setting is successful, returns true; otherwise returns false and sets
-    an error code which can be obtained by accessing the value of the
-    QSerialPort::error property. To set the baud rate, use the enumeration
-    QSerialPort::BaudRate or any positive qint32 value.
+    If the setting is successful or set before opening the port, returns true;
+    otherwise returns false and sets an error code which can be obtained by
+    accessing the value of the QSerialPort::error property. To set the baud
+    rate, use the enumeration QSerialPort::BaudRate or any positive qint32
+    value.
 
-    \note The serial port has to be open before trying to set this property;
-    otherwise returns false and sets the NotOpenError error code. This is a bit
-    unusual as opposed to the regular Qt property settings of a class. However,
-    this is a special use case since the property is set through the interaction
-    with the kernel and hardware. Hence, the two scenarios cannot be completely
-    compared to each other.
+    \note If the setting is set before opening the port, the actual serial port
+    setting is done automatically in the \l{QSerialPort::open()} method right
+    after that the opening of the port succeeds.
 
-    \warning Only the AllDirections flag is support for setting this property on
-    Windows, Windows CE, and Symbian.
+    \warning Setting the AllDirections flag is only supported on
+    the Windows, Windows CE, and Symbian platforms.
 
     \warning Returns equal baud rate in any direction on Windows, Windows CE, and
     Symbian.
+
+    The default value is Baud9600, i.e. 9600 bits per second.
 */
 bool QSerialPort::setBaudRate(qint32 baudRate, Directions directions)
 {
     Q_D(QSerialPort);
 
-    if (!isOpen()) {
-        setError(QSerialPort::NotOpenError);
-        qWarning("%s: device not open", Q_FUNC_INFO);
-        return false;
-    }
-
-    if (d->setBaudRate(baudRate, directions)) {
+    if (!isOpen() || d->setBaudRate(baudRate, directions)) {
         if (directions & QSerialPort::Input) {
             if (d->inputBaudRate != baudRate)
                 d->inputBaudRate = baudRate;
@@ -670,28 +663,21 @@ qint32 QSerialPort::baudRate(Directions directions) const
     \property QSerialPort::dataBits
     \brief the data bits in a frame
 
-    If the setting is successful, returns true; otherwise returns false and sets
-    an error code which can be obtained by accessing the value of the
-    QSerialPort::error property.
+    If the setting is successful or set before opening the port, returns
+    true; otherwise returns false and sets an error code which can be obtained
+    by accessing the value of the QSerialPort::error property.
 
-    \note The serial port has to be open before trying to set this property;
-    otherwise returns false and sets the NotOpenError error code. This is a bit
-    unusual as opposed to the regular Qt property settings of a class. However,
-    this is a special use case since the property is set through the interaction
-    with the kernel and hardware. Hence, the two scenarios cannot be completely
-    compared to each other.
+    \note If the setting is set before opening the port, the actual serial port
+    setting is done automatically in the \l{QSerialPort::open()} method right
+    after that the opening of the port succeeds.
+
+    The default value is Data8, i.e. 8 data bits.
 */
 bool QSerialPort::setDataBits(DataBits dataBits)
 {
     Q_D(QSerialPort);
 
-    if (!isOpen()) {
-        setError(QSerialPort::NotOpenError);
-        qWarning("%s: device not open", Q_FUNC_INFO);
-        return false;
-    }
-
-    if (d->setDataBits(dataBits)) {
+    if (!isOpen() || d->setDataBits(dataBits)) {
         if (d->dataBits != dataBits) {
             d->dataBits = dataBits;
             emit dataBitsChanged(d->dataBits);
@@ -722,28 +708,21 @@ QSerialPort::DataBits QSerialPort::dataBits() const
     \property QSerialPort::parity
     \brief the parity checking mode
 
-    If the setting is successful, returns true; otherwise returns false and sets
-    an error code which can be obtained by accessing the value of the
-    QSerialPort::error property.
+    If the setting is successful or set before opening the port, returns true;
+    otherwise returns false and sets an error code which can be obtained by
+    accessing the value of the QSerialPort::error property.
 
-    \note The serial port has to be open before trying to set this property;
-    otherwise returns false and sets the NotOpenError error code. This is a bit
-    unusual as opposed to the regular Qt property settings of a class. However,
-    this is a special use case since the property is set through the interaction
-    with the kernel and hardware. Hence, the two scenarios cannot be completely
-    compared to each other.
+    \note If the setting is set before opening the port, the actual serial port
+    setting is done automatically in the \l{QSerialPort::open()} method right
+    after that the opening of the port succeeds.
+
+    The default value is NoParity, i.e. no parity.
 */
 bool QSerialPort::setParity(Parity parity)
 {
     Q_D(QSerialPort);
 
-    if (!isOpen()) {
-        setError(QSerialPort::NotOpenError);
-        qWarning("%s: device not open", Q_FUNC_INFO);
-        return false;
-    }
-
-    if (d->setParity(parity)) {
+    if (!isOpen() || d->setParity(parity)) {
         if (d->parity != parity) {
             d->parity = parity;
             emit parityChanged(d->parity);
@@ -773,28 +752,21 @@ QSerialPort::Parity QSerialPort::parity() const
     \property QSerialPort::stopBits
     \brief the number of stop bits in a frame
 
-    If the setting is successful, returns true; otherwise returns false and
-    sets an error code which can be obtained by accessing the value of the
-    QSerialPort::error property.
+    If the setting is successful or set before opening the port, returns true;
+    otherwise returns false and sets an error code which can be obtained by
+    accessing the value of the QSerialPort::error property.
 
-    \note The serial port has to be open before trying to set this property;
-    otherwise returns false and sets the NotOpenError error code. This is a bit
-    unusual as opposed to the regular Qt property settings of a class. However,
-    this is a special use case since the property is set through the interaction
-    with the kernel and hardware. Hence, the two scenarios cannot be completely
-    compared to each other.
+    \note If the setting is set before opening the port, the actual serial port
+    setting is done automatically in the \l{QSerialPort::open()} method right
+    after that the opening of the port succeeds.
+
+    The default value is OneStop, i.e. 1 stop bit.
 */
 bool QSerialPort::setStopBits(StopBits stopBits)
 {
     Q_D(QSerialPort);
 
-    if (!isOpen()) {
-        setError(QSerialPort::NotOpenError);
-        qWarning("%s: device not open", Q_FUNC_INFO);
-        return false;
-    }
-
-    if (d->setStopBits(stopBits)) {
+    if (!isOpen() || d->setStopBits(stopBits)) {
         if (d->stopBits != stopBits) {
             d->stopBits = stopBits;
             emit stopBitsChanged(d->stopBits);
@@ -824,31 +796,24 @@ QSerialPort::StopBits QSerialPort::stopBits() const
     \property QSerialPort::flowControl
     \brief the desired flow control mode
 
-    If the setting is successful, returns true; otherwise returns false and sets
-    an error code which can be obtained by accessing the value of the
-    QSerialPort::error property.
+    If the setting is successful or set before opening the port, returns true;
+    otherwise returns false and sets an error code which can be obtained by
+    accessing the value of the QSerialPort::error property.
 
-    \note The serial port has to be open before trying to set this property;
-    otherwise returns false and sets the NotOpenError error code. This is a bit
-    unusual as opposed to the regular Qt property settings of a class. However,
-    this is a special use case since the property is set through the interaction
-    with the kernel and hardware. Hence, the two scenarios cannot be completely
-    compared to each other.
+    \note If the setting is set before opening the port, the actual serial port
+    setting is done automatically in the \l{QSerialPort::open()} method right
+    after that the opening of the port succeeds.
+
+    The default value is NoFlowControl, i.e. no flow control.
 */
-bool QSerialPort::setFlowControl(FlowControl flow)
+bool QSerialPort::setFlowControl(FlowControl flowControl)
 {
     Q_D(QSerialPort);
 
-    if (!isOpen()) {
-        setError(QSerialPort::NotOpenError);
-        qWarning("%s: device not open", Q_FUNC_INFO);
-        return false;
-    }
-
-    if (d->setFlowControl(flow)) {
-        if (d->flow != flow) {
-            d->flow = flow;
-            emit flowControlChanged(d->flow);
+    if (!isOpen() || d->setFlowControl(flowControl)) {
+        if (d->flowControl != flowControl) {
+            d->flowControl = flowControl;
+            emit flowControlChanged(d->flowControl);
         }
         return true;
     }
@@ -859,7 +824,7 @@ bool QSerialPort::setFlowControl(FlowControl flow)
 QSerialPort::FlowControl QSerialPort::flowControl() const
 {
     Q_D(const QSerialPort);
-    return d->flow;
+    return d->flowControl;
 }
 
 /*!
@@ -875,15 +840,12 @@ QSerialPort::FlowControl QSerialPort::flowControl() const
     \property QSerialPort::dataTerminalReady
     \brief the state (high or low) of the line signal DTR
 
-    If the setting is successful, returns true; otherwise returns false.
+    Returns true on success, false otherwise.
     If the flag is true then the DTR signal is set to high; otherwise low.
 
     \note The serial port has to be open before trying to set or get this
-    property; otherwise returns false and sets the NotOpenError error code. This
-    is a bit unusual as opposed to the regular Qt property settings of a class.
-    However, this is a special use case since the property is set through the
-    interaction with the kernel and hardware. Hence, the two scenarios cannot be
-    completely compared to each other.
+    property; otherwise false is returned and the error code is set to
+    NotOpenError.
 
     \sa pinoutSignals()
 */
@@ -897,11 +859,10 @@ bool QSerialPort::setDataTerminalReady(bool set)
         return false;
     }
 
-    bool retval = d->setDataTerminalReady(set);
-    if (retval && (d->dataTerminalReady != set)) {
-        d->dataTerminalReady = set;
+    const bool dataTerminalReady = isDataTerminalReady();
+    const bool retval = d->setDataTerminalReady(set);
+    if (retval && (dataTerminalReady != set))
         emit dataTerminalReadyChanged(set);
-    }
 
     return retval;
 }
@@ -926,15 +887,12 @@ bool QSerialPort::isDataTerminalReady()
     \property QSerialPort::requestToSend
     \brief the state (high or low) of the line signal RTS
 
-    If the setting is successful, returns true; otherwise returns false.
+    Returns true on success, false otherwise.
     If the flag is true then the RTS signal is set to high; otherwise low.
 
     \note The serial port has to be open before trying to set or get this
-    property; otherwise returns false and sets the NotOpenError error code. This
-    is a bit unusual as opposed to the regular Qt property settings of a class.
-    However, this is a special use case since the property is set through the
-    interaction with the kernel and hardware. Hence, the two scenarios cannot be
-    completely compared to each other.
+    property; otherwise false is returned and the error code is set to
+    NotOpenError.
 
     \sa pinoutSignals()
 */
@@ -948,11 +906,10 @@ bool QSerialPort::setRequestToSend(bool set)
         return false;
     }
 
-    bool retval = d->setRequestToSend(set);
-    if (retval && (d->requestToSend != set)) {
-        d->requestToSend = set;
+    const bool requestToSend = isRequestToSend();
+    const bool retval = d->setRequestToSend(set);
+    if (retval && (requestToSend != set))
         emit requestToSendChanged(set);
-    }
 
     return retval;
 }
@@ -1034,7 +991,7 @@ bool QSerialPort::flush()
 
 /*!
     Discards all characters from the output or input buffer, depending on
-    given directions \a directions. Including clear an internal class buffers and
+    given directions \a directions. This includes clearing the internal class buffers and
     the UART (driver) buffers. Also terminate pending read or write operations.
     If successful, returns true; otherwise returns false.
 
@@ -1088,8 +1045,8 @@ bool QSerialPort::atEnd() const
 
 /*!
     \property QSerialPort::dataErrorPolicy
-    \brief the error policy how the process receives the character in case of
-    parity error detection.
+    \brief the error policy for how the process receives characters in the case where
+    a parity error is detected.
     \obsolete
 
     If the setting is successful, returns true; otherwise returns false. The
@@ -1102,6 +1059,7 @@ bool QSerialPort::atEnd() const
     with the kernel and hardware. Hence, the two scenarios cannot be completely
     compared to each other.
 */
+#if QT_DEPRECATED_SINCE(5, 2)
 bool QSerialPort::setDataErrorPolicy(DataErrorPolicy policy)
 {
     Q_D(QSerialPort);
@@ -1126,14 +1084,14 @@ QSerialPort::DataErrorPolicy QSerialPort::dataErrorPolicy() const
     Q_D(const QSerialPort);
     return d->policy;
 }
-
+#endif // QT_DEPRECATED_SINCE(5, 2)
 /*!
     \fn void QSerialPort::dataErrorPolicyChanged(DataErrorPolicy policy)
     \obsolete
 
-    This signal is emitted after the error policy how the process receives the
-    character in case of parity error detection has been changed. The new error
-    policy how the process receives the character in case of parity error
+    This signal is emitted after the error policy for how the process receives
+    characters in case of parity error detection has been changed. The new error
+    policy for how the process receives the character in case of parity error
     detection is passed as \a policy.
 
     \sa QSerialPort::dataErrorPolicy
@@ -1164,8 +1122,8 @@ void QSerialPort::clearError()
 /*!
     \fn void QSerialPort::error(SerialPortError error)
 
-    This signal is emitted after the error has been changed. The new erroris
-    passed as \a error.
+    This signal is emitted after the error has been changed. The new error
+    is passed as \a error.
 
     \sa QSerialPort::error
 */
@@ -1191,14 +1149,14 @@ qint64 QSerialPort::readBufferSize() const
     size bytes.
 
     If the buffer size is limited to a certain size, QSerialPort
-    will not buffer more than this size of data. Exceptionally, a buffer
+    will not buffer more than this size of data. The special case of a buffer
     size of 0 means that the read buffer is unlimited and all
     incoming data is buffered. This is the default.
 
     This option is useful if the data is only read at certain points
     in time (for instance in a real-time streaming application) or if the serial
     port should be protected against receiving too much data, which may
-    eventually causes that the application runs out of memory.
+    eventually cause the application to run out of memory.
 
     \sa readBufferSize(), read()
 */
@@ -1246,7 +1204,7 @@ qint64 QSerialPort::bytesAvailable() const
 qint64 QSerialPort::bytesToWrite() const
 {
     Q_D(const QSerialPort);
-    return d->writeBuffer.size() + QIODevice::bytesToWrite();
+    return d->bytesToWrite() + QIODevice::bytesToWrite();
 }
 
 /*!
@@ -1287,8 +1245,8 @@ bool QSerialPort::waitForReadyRead(int msecs)
     \fn Handle QSerialPort::handle() const
     \since 5.2
 
-    Returns the native serial port descriptor of the object. If the serial port
-    is not open or the platform is not supported, handle() returns -1.
+    If the platform is supported and the serial port is open, returns the native
+    serial port handle; otherwise returns -1.
 
     \warning This function is for expert use only; use it at your own risk.
     Furthermore, this function carries no compatibility promise between minor
@@ -1363,7 +1321,7 @@ bool QSerialPort::setBreakEnabled(bool set)
 qint64 QSerialPort::readData(char *data, qint64 maxSize)
 {
     Q_D(QSerialPort);
-    return d->readBuffer.read(data, maxSize);
+    return d->readData(data, maxSize);
 }
 
 /*!
@@ -1380,7 +1338,7 @@ qint64 QSerialPort::readLineData(char *data, qint64 maxSize)
 qint64 QSerialPort::writeData(const char *data, qint64 maxSize)
 {
     Q_D(QSerialPort);
-    return d->writeToBuffer(data, maxSize);
+    return d->writeData(data, maxSize);
 }
 
 void QSerialPort::setError(QSerialPort::SerialPortError serialPortError, const QString &errorString)
